==> CRM64Pro-0.14.0-docs.zip: CRM64Pro-0.14.0-docs/html/group___image_m.js <==
var group___image_m =
[
    [ "CRM64Pro::Image", "class_c_r_m64_pro_1_1_image.html", [
      [ "info", "class_c_r_m64_pro_1_1_image.html#a80e2022e45b4ae23086fdc0379ffbd6e", null ],
      [ "getName", "class_c_r_m64_pro_1_1_image.html#a02e0bc02743a80b477c255b6c2007896", null ],
      [ "getID", "class_c_r_m64_pro_1_1_image.html#ae87ea9307eda8c479e077ea093858ff7", null ],
      [ "assignSurface", "class_c_r_m64_pro_1_1_image.html#a174f24d5480fb168517c4448c83620c7", null ],
      [ "setOwner", "class_c_r_m64_pro_1_1_image.html#a0408a62f436ef6ae0f8033d6313bd994", null ],
      [ "getOwner", "class_c_r_m64_pro_1_1_image.html#a90d162cab7c75e0c6d6364dda3b08fd7", null ],
      [ "optimize", "class_c_r_m64_pro_1_1_image.html#ab263064928ee207392b10ccb72745c12", null ],
      [ "rebuild", "class_c_r_m64_pro_1_1_image.html#a30b9c9a910082070136bf52fab2d9e0e", null ],
      [ "render", "class_c_r_m64_pro_1_1_image.html#a5b3ba2b8c676338b6b54c12595d36486", null ],
      [ "renderEx", "class_c_r_m64_pro_1_1_image.html#a3d6452ab996492005f441f33a45d2477", null ],
      [ "applyFilter", "class_c_r_m64_pro_1_1_image.html#a1de85d42e7684f13cd56aa20647d0f60", null ],
      [ "setBlendMode", "class_c_r_m64_pro_1_1_image.html#ad3e4488a56c799d04f42fdc72c75e16c", null ],
      [ "getBlendMode", "class_c_r_m64_pro_1_1_image.html#a9cfba7f99da52fce2e8fec022db0f698", null ],
      [ "setAlphaMod", "class_c_r_m64_pro_1_1_image.html#ae2959fa573d8aa0c235f456682d9d4c6", null ],
      [ "getAlphaMod", "class_c_r_m64_pro_1_1_image.html#a52ecc0c0ec11f8b1b1090fa019ba92bd", null ],
      [ "setColorMod", "class_c_r_m64_pro_1_1_image.html#a3d02cfa74d260308d95d911bd2945554", null ],
      [ "getColorMod", "class_c_r_m64_pro_1_1_image.html#aa4c360ce9b6f8365580ef7f32d920b6e", null ],
      [ "setColorKey", "class_c_r_m64_pro_1_1_image.html#a1a3a3d19b2cb812163628bb1c88f7cdc", null ],
      [ "getColorKey", "class_c_r_m64_pro_1_1_image.html#a9bd58789a5400814f774fcb3a903b76a", null ],
      [ "getSurface", "class_c_r_m64_pro_1_1_image.html#a1df3d8c66ebc4b2786725e10dc467f97", null ],
      [ "findTex", "class_c_r_m64_pro_1_1_image.html#a1c0fafe62fda2cc314341df970733391", null ],
      [ "saveToBMP", "class_c_r_m64_pro_1_1_image.html#aa33c2d7cb47cefed8c42a24483e8cee5", null ],
      [ "saveToPNG", "class_c_r_m64_pro_1_1_image.html#a9af49ed74b7f3bb61682b900692bbf7a", null ],
      [ "save", "class_c_r_m64_pro_1_1_image.html#af0b7b3fbc38941a59e9391617cc64fcc", null ],
      [ "save", "class_c_r_m64_pro_1_1_image.html#a661957aa64a987a69e697ad79f2a1a21", null ]
    ] ],
    [ "CRM64Pro::ImageMgr", "class_c_r_m64_pro_1_1_image_mgr.html", [
      [ "info", "class_c_r_m64_pro_1_1_image_mgr.html#a6f448b82c1d5d83c465132d65ee4865b", null ],
      [ "create", "class_c_r_m64_pro_1_1_image_mgr.html#ab487681c83881574d70bfd0957ad8c0b", null ],
      [ "close", "class_c_r_m64_pro_1_1_image_mgr.html#a407f828e6aecfb2ce3884f8f420cc729", null ],
      [ "getCount", "class_c_r_m64_pro_1_1_image_mgr.html#af13ecb96855d2b6053b62f4c878b9e79", null ],
      [ "setName", "class_c_r_m64_pro_1_1_image_mgr.html#a3b9f3195762b2f9aeb4f896184187763", null ],
      [ "closeEx", "class_c_r_m64_pro_1_1_image_mgr.html#a94d2eff703e8404c3818136a2c459f4a", null ],
      [ "get", "class_c_r_m64_pro_1_1_image_mgr.html#a00dd21497a886f254374bf6ce6c4a03e", null ],
      [ "duplicate", "class_c_r_m64_pro_1_1_image_mgr.html#a74356dc9579b0c32152e3719f903f621", null ],
      [ "child", "class_c_r_m64_pro_1_1_image_mgr.html#a65f604f8c21fc04cd447b9eb54d41909", null ],
      [ "isBMP", "class_c_r_m64_pro_1_1_image_mgr.html#a1f0ff44a7d66053ce11e47b888529f10", null ],
      [ "isPNG", "class_c_r_m64_pro_1_1_image_mgr.html#ae7b074ce8fbfcadcb3bf3529d0550121", null ],
      [ "loadFromFile", "class_c_r_m64_pro_1_1_image_mgr.html#a207bbd2d50cda5e1358137a601e81fc1", null ],
      [ "load", "class_c_r_m64_pro_1_1_image_mgr.html#a53945a4290c32b2eab80a5d4e0b88e48", null ],
      [ "load", "class_c_r_m64_pro_1_1_image_mgr.html#ac76573d38ed9d4ccabcfa027ae8af72b", null ],
      [ "loadFromBuffer", "class_c_r_m64_pro_1_1_image_mgr.html#a150e1702078ece69eba5d8ed1c82e12b", null ],
      [ "remove", "class_c_r_m64_pro_1_1_image_mgr.html#ae5a2d1147172fb1301357a1819d7a8de", null ],
      [ "exist", "class_c_r_m64_pro_1_1_image_mgr.html#ad0a2576537f2b3dbf666c5ac36600bfb", null ],
      [ "exist", "class_c_r_m64_pro_1_1_image_mgr.html#a0fbb5dd5826186501358cd9efa0c18c3", null ]
    ] ],
    [ "CRM64Pro::eImageFilter", "group___image_m.html#gaf737f1c1321cc142edd87bad513fde1a", [
      [ "CRM64Pro::IF_NOISE", "group___image_m.html#ggaf737f1c1321cc142edd87bad513fde1aa9c48a79b0217b1d24bc70853a44f0d34", null ],
      [ "CRM64Pro::IF_BLUR", "group___image_m.html#ggaf737f1c1321cc142edd87bad513fde1aa279d45f980d647a00569b814dc5a35bc", null ],
      [ "CRM64Pro::IF_NEGATIVE", "group___image_m.html#ggaf737f1c1321cc142edd87bad513fde1aacaf2f8c1b3bc4790bbdbc4695cc5bad8", null ],
      [ "CRM64Pro::IF_GREY", "group___image_m.html#ggaf737f1c1321cc142edd87bad513fde1aa3bc2b7e92bb04985043d53075805b05c", null ],
      [ "CRM64Pro::IF_BW", "group___image_m.html#ggaf737f1c1321cc142edd87bad513fde1aaa94371f6b2731fc3fa13fe9ec2560643", null ],
      [ "CRM64Pro::IF_WIGGLE", "group___image_m.html#ggaf737f1c1321cc142edd87bad513fde1aa462d35aef81bfd09cfe1464ddf98de79", null ],
      [ "CRM64Pro::IF_PIXELATE", "group___image_m.html#ggaf737f1c1321cc142edd87bad513fde1aab5342900bfaf4b146e031f8f14684a71", null ]
    ] ]
];

==> CRM64Pro-0.15.0-docs.zip: CRM64Pro-0.15.0-docs/html/group___image_m.js <==
var group___image_m =
[
    [ "CRM64Pro::Image", "class_c_r_m64_pro_1_1_image.html", [
      [ "info", "class_c_r_m64_pro_1_1_image.html#a80e2022e45b4ae23086fdc0379ffbd6e", null ],
      [ "getName", "class_c_r_m64_pro_1_1_image.html#a02e0bc02743a80b477c255b6c2007896", null ],
      [ "getID", "class_c_r_m64_pro_1_1_image.html#ae87ea9307eda8c479e077ea093858ff7", null ],
      [ "assignSurface", "class_c_r_m64_pro_1_1_image.html#a174f24d5480fb168517c4448c83620c7", null ],
      [ "setOwner", "class_c_r_m64_pro_1_1_image.html#a0408a62f436ef6ae0f8033d6313bd994", null ],
      [ "getOwner", "class_c_r_m64_pro_1_1_image.html#a90d162cab7c75e0c6d6364dda3b08fd7", null ],
      [ "optimize", "class_c_r_m64_pro_1_1_image.html#ab263064928ee207392b10ccb72745c12", null ],
      [ "rebuild", "class_c_r_m64_pro_1_1_image.html#a30b9c9a910082070136bf52fab2d9e0e", null ],
      [ "render", "class_c_r_m64_pro_1_1_image.html#a5b3ba2b8c676338b6b54c12595d36486", null ],
      [ "renderEx", "class_c_r_m64_pro_1_1_image.html#a3d6452ab996492005f441f33a45d2477", null ],
      [ "applyFilter", "class_c_r_m64_pro_1_1_image.html#a1de85d42e7684f13cd56aa20647d0f60", null ],
      [ "setBlendMode", "class_c_r_m64_pro_1_1_image.html#ad3e4488a56c799d04f42fdc72c75e16c", null ],
      [ "getBlendMode", "class_c_r_m64_pro_1_1_image.html#a9cfba7f99da52fce2e8fec022db0f698", null ],
      [ "setAlphaMod", "class_c_r_m64_pro_1_1_image.html#ae2959fa573d8aa0c235f456682d9d4c6", null ],
      [ "getAlphaMod", "class_c_r_m64_pro_1_1_image.html#a52ecc0c0ec11f8b1b1090fa019ba92bd", null ],
      [ "setColorMod", "class_c_r_m64_pro_1_1_image.html#a3d02cfa74d260308d95d911bd2945554", null ],
      [ "getColorMod", "class_c_r_m64_pro_1_1_image.html#aa4c360ce9b6f8365580ef7f32d920b6e", null ],
      [ "setColorKey", "class_c_r_m64_pro_1_1_image.html#a1a3a3d19b2cb812163628bb1c88f7cdc", null ],
      [ "getColorKey", "class_c_r_m64_pro_1_1_image.html#a9bd58789a5400814f774fcb3a903b76a", null ],
      [ "getSurface", "class_c_r_m64_pro_1_1_image.html#a1df3d8c66ebc4b2786725e10dc467f97", null ],
      [ "getWidth", "class_c_r_m64_pro_1_1_image.html#abe571c3ca7db1742c68e50da435b2b69", null ],
      [ "getHeight", "class_c_r_m64_pro_1_1_image.html#a3014f9ece2a15b787e972b484683a3cf", null ],
      [ "findTex", "class_c_r_m64_pro_1_1_image.html#a1c0fafe62fda2cc314341df970733391", null ],
      [ "saveToBMP", "class_c_r_m64_pro_1_1_image.html#aa33c2d7cb47cefed8c42a24483e8cee5", null ],
      [ "saveToPNG", "class_c_r_m64_pro_1_1_image.html#a9af49ed74b7f3bb61682b900692bbf7a", null ],
      [ "save", "class_c_r_m64_pro_1_1_image.html#af0b7b3fbc38941a59e9391617cc64fcc", null ],
      [ "save", "class_c_r_m64_pro_1_1_image.html#a661957aa64a987a69e697ad79f2a1a21", null ]
    ] ],
    [ "CRM64Pro::ImageMgr", "class_c_r_m64_pro_1_1_image_mgr.html", [
      [ "info", "class_c_r_m64_pro_1_1_image_mgr.html#a6f448b82c1d5d83c465132d65ee4865b", null ],
      [ "create", "class_c_r_m64_pro_1_1_image_mgr.html#ab487681c83881574d70bfd0957ad8c0b", null ],
      [ "close", "class_c_r_m64_pro_1_1_image_mgr.html#a407f828e6aecfb2ce3884f8f420cc729", null ],
      [ "getCount", "class_c_r_m64_pro_1_1_image_mgr.html#af13ecb96855d2b6053b62f4c878b9e79", null ],
      [ "setName", "class_c_r_m64_pro_1_1_image_mgr.html#a3b9f3195762b2f9aeb4f896184187763", null ],
      [ "closeEx", "class_c_r_m64_pro_1_1_image_mgr.html#a94d2eff703e8404c3818136a2c459f4a", null ],
      [ "get", "class_c_r_m64_pro_1_1_image_mgr.html#a00dd21497a886f254374bf6ce6c4a03e", null ],
      [ "duplicate", "class_c_r_m64_pro_1_1_image_mgr.html#a74356dc9579b0c32152e3719f903f621", null ],
      [ "child", "class_c_r_m64_pro_1_1_image_mgr.html#a65f604f8c21fc04cd447b9eb54d41909", null ],
      [ "isBMP", "class_c_r_m64_pro_1_1_image_mgr.html#a1f0ff44a7d66053ce11e47b888529f10", null ],
      [ "isPNG", "class_c_r_m64_pro_1_1_image_mgr.html#ae7b074ce8fbfcadcb3bf3529d0550121", null ],
      [ "loadFromFile", "class_c_r_m64_pro_1_1_image_mgr.html#a207bbd2d50cda5e1358137a601e81fc1", null ],
      [ "load", "class_c_r_m64_pro_1_1_image_mgr.html#a53945a4290c32b2eab80a5d4e0b88e48", null ],
      [ "load", "class_c_r_m64_pro_1_1_image_mgr.html#ac76573d38ed9d4ccabcfa027ae8af72b", null ],
      [ "loadFromBuffer", "class_c_r_m64_pro_1_1_image_mgr.html#a150e1702078ece69eba5d8ed1c82e12b", null ],
      [ "loadFromSurface", "class_c_r_m64_pro_1_1_image_mgr.html#ab91930390fa658b080083fa3c0050b0e", null ],
      [ "remove", "class_c_r_m64_pro_1_1_image_mgr.html#ae5a2d1147172fb1301357a1819d7a8de", null ],
      [ "exist", "class_c_r_m64_pro_1_1_image_mgr.html#ad0a2576537f2b3dbf666c5ac36600bfb", null ],
      [ "exist", "class_c_r_m64_pro_1_1_image_mgr.html#a0fbb5dd5826186501358cd9efa0c18c3", null ]
    ] ],
    [ "CRM64Pro::eImageFilter", "group___image_m.html#gaf737f1c1321cc142edd87bad513fde1a", [
      [ "CRM64Pro::IF_NOISE", "group___image_m.html#ggaf737f1c1321cc142edd87bad513fde1aa9c48a79b0217b1d24bc70853a44f0d34", null ],
      [ "CRM64Pro::IF_BLUR", "group___image_m.html#ggaf737f1c1321cc142edd87bad513fde1aa279d45f980d647a00569b814dc5a35bc", null ],
      [ "CRM64Pro::IF_NEGATIVE", "group___image_m.html#ggaf737f1c1321cc142edd87bad513fde1aacaf2f8c1b3bc4790bbdbc4695cc5bad8", null ],
      [ "CRM64Pro::IF_GREY", "group___image_m.html#ggaf737f1c1321cc142edd87bad513fde1aa3bc2b7e92bb04985043d53075805b05c", null ],
      [ "CRM64Pro::IF_BW", "group___image_m.html#ggaf737f1c1321cc142edd87bad513fde1aaa94371f6b2731fc3fa13fe9ec2560643", null ],
      [ "CRM64Pro::IF_WIGGLE", "group___image_m.html#ggaf737f1c1321cc142edd87bad513fde1aa462d35aef81bfd09cfe1464ddf98de79", null ],
      [ "CRM64Pro::IF_PIXELATE", "group___image_m.html#ggaf737f1c1321cc142edd87bad513fde1aab5342900bfaf4b146e031f8f14684a71", null ]
    ] ]
];
